## SecretColors

Library generated for making plots with better color palette. It uses  famous color palettes and adds few helpful functions. 

Currently it supports following Color Palettes

- IBM Color Palette
- Google Material Design Color Palette
- ColorBrewer2 Color Palette
- VMWare Clarity Color Palette 
- Tableau Color Palette

You can get output of colors in variety of color formats including `hex` , `rgb` , `hsl`, `rgba` etc. 

Few sample plots and inspiration behind this library can be found in [WeirdData blog](https://weirddata.github.io/2019/06/11/secret-colors-2.html). 

### Installation 

```
pip install SecretColors
```

### Documentation

Full documentation and API reference can be accessed via [ReadTheDocs](https://secretcolors.readthedocs.io) 

For latest information regarding this library, visit our [website](https://github.com/secretBiology/SecretColors). 

### License 

This library and its code is released under MIT License . Read full statement [here](https://github.com/secretBiology/SecretColors/blob/master/LICENSE). 